@@ -1,7 +1,8 @@
 """Simple configuration management with python"""
-__version__ = "0.2.1"
+__version__ = "0.3.0"
 import re
 import ast
+import hashlib
 from os import path
 from collections import OrderedDict
 from contextlib import contextmanager
@@ -45,8 +46,8 @@ class Loader:
 		return val
 
 	def __init__(self, cfile, with_profile):
-		self.withProfile = with_profile
-		self.conf        = self.load(cfile)
+		self.with_profile = with_profile
+		self.conf         = self.load(cfile)
 
 	def load(self, cfile):
 		"""Defines how the configuration file should be loaded"""
@@ -71,7 +72,7 @@ class IniLoader(Loader):
 		defaults.update(ret.get('default', {}))
 		ret['default'] = defaults
 
-		if not self.withProfile:
+		if not self.with_profile:
 			# only default session is loaded
 			return {key: Loader.typeCast(val) for key, val in defaults.items()}
 
@@ -93,7 +94,7 @@ class EnvLoader(Loader):
 		# default_A = 1
 		conf = DotEnv(cfile).dict()
 
-		if not self.withProfile:
+		if not self.with_profile:
 			return {key: Loader.typeCast(val) for key, val in conf.items()}
 
 		ret = {}
@@ -117,7 +118,7 @@ class OsEnvLoader(Loader):
 				continue
 			key = key[len(prefix):]
 
-			if not self.withProfile:
+			if not self.with_profile:
 				conf[key] = Loader.typeCast(val)
 				continue
 
@@ -210,34 +211,46 @@ class Config(Diot):
 		with_profile   = self._protected['with_profile']
 		profile        = self._protected['profile']
 		for name in names:
-			ext = 'dict' if isinstance(name, dict) else str(name).rpartition('.')[2]
+			ext = 'config'	if isinstance(name, Config) else 'dict' \
+							if isinstance(name, dict) else str(name).rpartition('.')[2]
 			if ext.endswith('rc'):
 				ext = 'ini'
+			if ext == 'config':
+				cached.update(name._protected['cached'])
+				for cname in name._protected['cached']:
+					if with_profile:
+						self._protected['profiles'] = self._profiles | set(cached[cname].keys())
+						self.update(cached[cname].get(profile, {}))
+					else:
+						self.update(cached[cname])
+				continue
 			if ext not in LOADERS:
 				raise FormatNotSupported(ext)
+
 			if ext == 'dict':
-				if repr(name) not in cached:
-					cached[repr(name)] = DictLoader(name, with_profile).conf
-				name = repr(name)
+				rname = hashlib.sha256(str(sorted(name.items())).encode()).hexdigest()
+				if rname not in cached:
+					cached[rname] = DictLoader(name, with_profile).conf
 				if with_profile:
-					self._protected['profiles'] = self._profiles | set(cached[name].keys())
+					self._protected['profiles'] = self._profiles | set(cached[rname].keys())
 			else:
 				# maybe hash the name?
-				name = str(name)
-				if name not in cached:
-					cached[name] = LOADERS[ext](name, with_profile).conf
+				rname = hashlib.sha256(str(name).encode()).hexdigest()
+				if rname not in cached:
+					cached[rname] = LOADERS[ext](name, with_profile).conf
 					if with_profile:
-						self._protected['profiles'] = self._profiles | set(cached[name].keys())
+						self._protected['profiles'] = self._profiles | set(cached[rname].keys())
 				else:
 					# change the position of the configuration
-					cached[name] = cached.pop(name)
+					cached[rname] = cached.pop(rname)
 
 			if with_profile:
-				self.update(cached[name].get(profile, {}))
+				self.update(cached[rname].get(profile, {}))
 			else:
-				self.update(cached[name])
+				self.update(cached[rname])
 
 	def copy(self, profile = None, base = None): # pylint: disable=arguments-differ
+		"""Copy the configuration"""
 		ret = self.__class__(with_profile = self._protected['with_profile'], **self)
 		ret._protected['profile']  = self._profile
 		ret._protected['cached']   = self._protected['cached'].copy()
@@ -247,6 +260,7 @@ class Config(Diot):
 		return ret
 
 	def clear(self):
+		"""Clear the configuration"""
 		super(Config, self).clear()
 		self._protected['cached'] = OrderedDict()
 
